@@ -13,18 +13,13 @@ class RSA (HomomorphicCryptosystem):
             q = prime(size)
             if p != q:
                 break
-        e = 65537
-        return RSA(p=p, q=q, e=e)
+        e = prime(size // 2)
+        return RSA(p, q, e)
 
-    def __init__ (self, **kwargs):
-        self._p = kwargs['p']
-        self._q = kwargs['q']
-
-        self._N = self._p * self._q
-
-        self._e = kwargs['e']
-
-        self._d = modinv(self._e, (self._p - 1) * (self._q - 1))
+    def __init__ (self, p, q, e):
+        self._N = p * q
+        self._e = e
+        self._d = modinv(e, (p - 1) * (q - 1))
 
     def get_modulus (self):
         return self._N
