@@ -3,46 +3,34 @@ from .. import THC
 from ..utils import prime
 from ..crypto.trivial import Trivial
 from ..crypto.rsa import RSA
+from ..crypto.elgamal import ElGamal
 from ..crypto.paillier import Paillier
 from ..crypto.he1 import HE1
-from ._computations import Product, RandomPolynomial
+from ._computations import Product, PairProduct, RandomPolynomial
 
 if __name__ ==  '__main__':
 
-    ### Trivial
-
-    p = prime(512)
-    q = prime(512)
-    r = prime(32)
     nums = random.sample(range(2**8), 5)
-    rp = RandomPolynomial(5, 2**8)
-
-    print('p =', p)
-    print('q =', q)
-    print('r =', r)
-    print('random numbers =', nums)
-    print('random polynomial P(x) =', rp)
-
-    print('')
-
-    thc = THC(Trivial(m=p), rp, r)
-    print('> P in F_p:')
-    for n in nums:
-        print('P(' + str(n) + ') =', thc.compute([n]))
-
-    print('')
 
     ### RSA
 
-    thc = THC(RSA(p=p, q=q, e=(1<<16)+1), Product(), r)
+    thc = THC(RSA.new(512), Product(), prime(32))
     print('> Multiplications with RSA:')
     print(' * '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
 
     print('')
 
+    ### ElGamal
+
+    thc = THC(ElGamal.new(512), PairProduct(), prime(32))
+    print('> Multiplications with ElGamal:')
+    print(' * '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
+
+    print('')
+
     ### Paillier
 
-    thc = THC(Paillier(p=p, q=q), Product(), r)
+    thc = THC(Paillier.new(512), Product(), prime(32))
     print('> Additions with Paillier:')
     print(' + '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
 
@@ -50,7 +38,9 @@ if __name__ ==  '__main__':
 
     ### HE1
 
-    thc = THC(HE1(p=p, q=q), rp, r)
-    print('> P with HE1:')
+    rp = RandomPolynomial(5, 2**8)
+    thc = THC(HE1.new(256), rp, prime(32))
+    print('> Polynomial with HE1:')
+    print('random polynomial P(x) =', rp)
     for n in nums:
         print('P(' + str(n) + ') =', thc.compute([n]))
