@@ -1,12 +1,12 @@
-from Crypto.Util.number import getPrime, getStrongPrime, inverse
-from Crypto.Random.random import StrongRandom
+from Cryptodome.Util.number import getPrime, getStrongPrime, inverse
+from Cryptodome.Random.random import StrongRandom
 
 ###
 ### Utils
 ###
 
 def prime (bits):
-    if bits >= 512 and bits % 128 == 0:
+    if bits > 512 and bits % 128 == 0:
         return getStrongPrime(bits)
     return getPrime(bits)
 
